@@ -627,6 +627,43 @@ static GtkWidget *build_keyboard(GtkWidget *input, char *filename)
 	  gtk_box_pack_start(GTK_BOX(mainbox), align, FALSE, FALSE, 0);
      } /* End for */
 
+     if(filename)
+     {
+          if(options.keyboard_file)
+          {
+               /* We just built a complete keyboard with this file, so save its
+                * name for future use.
+                */
+               /* This weird indirect freeing and copying of the string is
+                * due to the fact that the filename argument to this function
+                * may in fact be options.keyboard_file itself, so in that
+                * case it wouldn't be that bright to try to free it and 
+                * copy something that's pointing to the same location.  So
+                * instead we copy it to an intermediate spot, free the 
+                * original, and copy the new value back.
+                *
+                * When the value actually is options.keyboard_file, we do a 
+                * bit of redundant work, but oh well.
+                */
+               char *tptr;
+               tptr = g_strdup_(filename);
+               g_free_(options.keyboard_file);
+               options.keyboard_file = g_strdup_(tptr);
+               g_free_(tptr);
+               fprintf(Q,"options.keyboard_file set to be \"%s\"\n",
+                       options.keyboard_file);
+               fflush(Q);
+          } /* End if */
+          else 
+          {
+               /* No need to free it - just copy */
+               options.keyboard_file = g_strdup_(filename);
+               fprintf(Q,"options.keyboard_file set to be \"%s\"\n",
+                       options.keyboard_file);
+               fflush(Q);
+          } /* End else */
+     } /* End if */
+
      /* gtk_widget_show_all(mainbox); */
      return(mainbox);
 } /* End build_keyboard() */
@@ -1005,10 +1042,11 @@ static GtkWidget *build_cursorpad(GtkWidget *foo)
 
      gtk_signal_connect(GTK_OBJECT(about), "button_press_event",
 			GTK_SIGNAL_FUNC(program_info), 
-			(gpointer)INFO_ABOUT);
+                        GINT_TO_POINTER(INFO_CHANGELOG));
+
      gtk_signal_connect(GTK_OBJECT(license), "button_press_event",
 			GTK_SIGNAL_FUNC(program_info), 
-			(gpointer)INFO_LICENSE);
+			GINT_TO_POINTER(INFO_LICENSE));
 
      /* Make me some arrows, dammit. */
      arrows[0] = xpm_to_widget(foo, (gchar **)xpm_cursor_left);
